"""Project Configuration variables"""

##########################################################################
#
# APPLICATION MODULES
#
##########################################################################
DETECTOR = 'detector'
DETECTOR_TYPE = 'detector_type'
PHYSICAL_DETECTOR_UNIT = 'physical_detector_unit'
PARAMETER = 'parameter'
CONDITION = 'condition'
CALIBRATION = 'calibration'
CALIBRATION_CONSTANT = 'calibration_constant'
CALIBRATION_CONSTANT_VERSION = 'calibration_constant_version'
REPORT = 'report'

##########################################################################
#
# ACTIONS
#
##########################################################################
CREATE = 'CREATE'
DELETE = 'DELETE'
UPDATE = 'UPDATE'
GET = 'GET'
SET = 'SET'
